Function history_storage_value
pub const fn history_storage_value(block_hash: FixedBytes<32>) -> Uint<256, 4>Expand description
Encodes a block hash as the history contract storage value.
pub const fn history_storage_value(block_hash: FixedBytes<32>) -> Uint<256, 4>Encodes a block hash as the history contract storage value.